function y=plot_lc_mnstd(lon,lat,umn,vmn,major,minor,theta,scale);
%plot_lc_mnstd(lon,lat,umn,vmn,maj,min,theta,scale) plots mean velocity vectors
%  at locations specified by lon,lat (negative longitudes for western hemisphere)
%  and overlays standard deviation ellipses specified by rotation theta (radians
%  anticlockwise from east) of the major ellipse (major) and eccentricity given 
%  by the major and minor (minor) axes lengths.  The standard deviation ellipses
%  are drawn at the vector heads so that the variability of the velocity vector
%  can be more easily interpreted.  Vector midpoints are drawn at the lat/lon
%  positions.  Vectors and ellipses are scaled by the parameter 'scale'. 
%  Bathymetry contours are drawn at 100,200,500,1000,1500,2000,2500, and 3000m.

load gom1k_topo
load lc_arr_coords

dd=size(umn);
if (size(lon) ~= dd) | (size(lat) ~= dd) | (size(vmn)~=dd) | (size(major)~=dd) ...
    |(size(minor)~=dd) | (size(theta) ~=dd)
  error('Error: Dimensions of lon,lat,umn,vmn,major,minor, and theta must be equal')
end

sc=scale;


ff = figure('visible','off');
hold on;

land=HH;
land(HH>=0)=1;
land(HH<0)=nan;
cc=colormap(jet);
cc(end,:)=[.5 1 .5];
colormap(cc);
pcolor(elon,alat,land); shading flat; caxis([0 1]);

scatter(tlon,tlat,70,[.7 .7 .7],'filled')
contour(elon,alat,HH,[-3000 -2500 -2000 -1500 -1000 -500 -200 -100 0],'k','linewidth',.5);
axis equal
set(gca,'xlim',[-90 -83],'ylim',[23 29]);

for i=1:numel(lon)
 x1=lon(i)-0.5*umn(i)*sc;
 x2=lon(i)+0.5*umn(i)*sc;
 y1=lat(i)-0.5*vmn(i)*sc;
 y2=lat(i)+0.5*vmn(i)*sc;
 draw_arrow(x1,x2,y1,y2,0.4,30,[0 0 .7],1);
 if (major(i)>0)
  draw_ellipse(x2,y2,major(i)*sc,minor(i)*sc,theta(i),[0 0 .7],1,0);
 end
end
draw_arrow(-84.5,-84.5+0.1*sc,28.5,28.5,0.4,30,[0 0 .7],.5);
text(-84.5+.12*sc,28.6,'0.1 m/s');
axes_deg

