function [theta,maj,min,wr]=princax(u,v)
%usage: [theta,maj,min,wr]=princax(u,v)
%u,v are the eastward,northward velocity component time series
%theta = angle of maximum variance, (east = 0, north=pi/2)
%maj = major axis of principal ellipse (returned as stdev, not var)
%min = minor axis of principal ellipse
%wr = rotated time series, where real(wr) is aligned with the major axis
%Solves eqs. 4.3.23b and 4.3.24 from Emery and Thomson

  cv=cov(u,v);
  theta=0.5*atan2(2.*cv(2,1),(cv(1,1)-cv(2,2)));
  t1=cv(1,1)+cv(2,2);
  t2=sqrt((cv(1,1)-cv(2,2))^2+4*cv(2,1)^2);
  maj=sqrt(.5*(t1+t2));
  min=sqrt(.5*(t1-t2));
  w=complex(u,v);
  wr=w*exp(complex(0,-1.)*theta);

